pub fn create_l1_batch(number: u32) -> L1BatchHeaderExpand description
Creates an L1 batch header with the specified number and deterministic contents.
pub fn create_l1_batch(number: u32) -> L1BatchHeaderCreates an L1 batch header with the specified number and deterministic contents.